@@ -16,7 +16,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 #{{{sub new
 sub new {
@@ -164,29 +164,27 @@ sub upload_file {
 #{{{sub upload_from_file
 sub upload_from_file {
     my ( $content, $file, $fork_id, $number_of_forks ) = @_;
+    $fork_id         = defined $fork_id         ? $fork_id         : 0;
+    $number_of_forks = defined $number_of_forks ? $number_of_forks : 1;
     my $count = 0;
-    if ( defined $file && open my ($input), '<', $file ) {
+    if ( !defined $file ) {
+        croak 'File to upload from not defined';
+    }
+    if ( open my ($input), '<', $file ) {
         while (<$input>) {
             if ( $fork_id == ( $count++ % $number_of_forks ) ) {
                 chomp;
-                $_ =~ /^(.*?),(.*?)$/msx
+                $_ =~ /^(\S.*?),(\S.*?)$/msx
                   or croak 'Problem parsing content to add';
-                if ( defined $1 && defined $2 ) {
-                    my $local_path  = $1;
-                    my $remote_path = $2;
-                    $content->upload_file( $local_path, $remote_path, q{} );
-                    Apache::Sling::Print::print_result($content);
-                }
-                else {
-                    print "ERROR: Problem parsing content to add: \"$_\"\n"
-                      or croak 'Problem printing!';
-                }
+                my $local_path  = $1;
+                my $remote_path = $2;
+                $content->upload_file( $local_path, $remote_path, q{} );
+                Apache::Sling::Print::print_result($content);
             }
         }
         close $input or croak 'Problem closing input!';
     }
     else {
-        $file = ( defined $file ? $file : '' );
         croak "Problem opening file: '$file'";
     }
     return 1;
